@@ -17,7 +17,7 @@ class UserCheckInlineAdmin(AdminBaseMixin, admin.TabularInline):
         'reason', 'message', 'is_passed', # 'meta', 'user', 'created_at', 'updated_at',
     )
     fields = (
-        'reason', 'state', 'message', 'is_passed',
+        'reason', 'state', 'message', 'is_reviewed', 'is_passed',
     )
 
     def has_add_permission(self, request, obj):
