@@ -28,6 +28,7 @@ def set_check(
     state: Optional[str] = None,
     message: Optional[str] = None,
     meta: Optional[dict] = None,
+    is_reviewed: bool = False,
 ) -> UserCheck:
     return cases.set_check(
         get_registry(),
@@ -36,4 +37,5 @@ def set_check(
         state=state,
         message=message,
         meta=meta,
+        is_reviewed=is_reviewed,
     )
